@@ -7,11 +7,7 @@ from sklearn.metrics import classification_report
 
 from spadepp.models.xgboost import XGBoost
 
-from ..models.random_forest import RandomForest
-from ..models.lr import LR
 
-from ..models.sentence_transformer import TripleLossSentTransformer
-from ..models.transformer import Transformer
 from ..models.fcn import FCN
 from ..labeler import Oracle
 
